Description Author(s) See Also
R6 classes that represents atomic and coupled system dynamics models, static
models, scenarios (variables and values that constitute a system environment)
and the simulation output. Two or more atomic, static or coupled models can
be coupled to form a more complex model, that enables communication between
it's components during simulation.
A function to simulate system dynamics models; a wrapper around the
ode solver from the deSolve-package that solves the
initial value problem of first-order ordinary differential equations (ODE)
that specifies a model definition.
A function to build a coupled scenario from two or more component
scenarios of a complex system.
Functions to help in the auxiliary and/or algebraic equations definition
and in the transformation of the time series variables into temporal
functions.
All the sdsim package functionalities for atomic system dynamics models are
available in a intuitive graphical user interface application built with the
shiny web application framework.
Adauto Mancini, Bruno H. Pereira, Cristina F. Bazzano & Luis Barioni
sdsim Functions:
sdRunApp for launching the sdsim application for atomic models;
a shiny server interface,
sdModel for creating an atomic system dynamics model object,
sdStaticModel for creating a static system model object,
sdCoupledModel for creating a coupled system dynamics model
object,
sdLoadModel for loading a model from a sdsim XML file or from
the sdsim repository, see available models in sdRepository,
sdScenario for creating a system scenario object (it represents
the variables and values that constitute a system environment and that are
used to compute the equations of a model),
sdLoadScenario for loading a scenario from an EXCEL or XML
file and sdExcelTemplate for creating an empty template for a
sdsim scenario EXCEL file,
sdBuildCoupledScenario for creating a coupled scenario from two
or more component's scenarios of a coupled model,
sdSimulate for solving static, atomic or coupled models in a
given scenario merged with the defaults. Runs the simulation and outputs the
result in a sdOutput object with visualization methods,
sdInitEquations for creating a list of sorted equations from a
list of R-expressions and/or strings with the equations in R-format,
sdTemporalFunction for interpolating input time series
variables. It is automatically used in the scenario initialization,
see sdScenarioClass documentation.
Can be used to test how the interpolation will happen and prevent the
output of wrong values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.